@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Multilogin Plugin
-  * Copyright (c) 2003-2007 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2007 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -12,6 +12,49 @@
 
 
 
+/**
+  * Validate that this plugin is configured correctly
+  *
+  * @return boolean Whether or not there was a
+  *                 configuration error for this plugin.
+  *
+  */
+function multilogin_check_configuration_do()
+{
+
+   // only need to do this pre-1.5.2, as 1.5.2 will make this
+   // check for us automatically
+   //
+   if (!check_sm_version(1, 5, 2))
+   {
+
+      // try to find Compatibility, and then that it is v2.0.7+
+      //
+      if (!function_exists('check_plugin_version')
+       || !check_plugin_version('compatibility', 2, 0, 7, TRUE))
+      {
+         do_err('Multilogin plugin requires the Compatibility plugin version 2.0.7+', FALSE);
+         return TRUE;
+      }
+
+
+      // make sure configuration file exists
+      //
+      if (!load_config('multilogin', 'config.php', TRUE))
+      {
+         do_err('Multilogin plugin is missing its configuration file; please consult its INSTALL document', FALSE);
+         return TRUE;
+      }
+
+
+   }
+
+   return FALSE;
+
+}
+
+
+
 /**
   * store the user's IMAP server in the session
   *
@@ -32,10 +75,12 @@ function multilogin_registerIMAPServer_do($args)
    }
 
 
-   global $loginServer, $rememberLoginServer, $IMAPSelections;
+   global $IMAPSelections;
+   $loginServer = '';
+   $rememberLoginServer = FALSE;
 
-   sqgetGlobalVar('loginServer', $loginServer, SQ_FORM);
-   sqgetGlobalVar('rememberLoginServer', $rememberLoginServer, SQ_FORM);
+   sqGetGlobalVar('loginServer', $loginServer, SQ_FORM);
+   sqGetGlobalVar('rememberLoginServer', $rememberLoginServer, SQ_FORM);
 
 
    // can't use load_config here because compatibility
@@ -62,8 +107,8 @@ function multilogin_registerIMAPServer_do($args)
       }
       else
       {
-         sqsetcookie('rememberLoginServer', '', (time() - 3600));
-//         setcookie('rememberLoginServer', '', (time() - 3600));
+         sqsetcookie('rememberLoginServer', 'deleted', 1);
+//         setcookie('rememberLoginServer', 'deleted', 1);
       }
 
    }
@@ -91,6 +136,7 @@ function multilogin_registerIMAPServer_do($args)
    {
 
       include_once(SM_PATH . 'functions/display_messages.php');
+      sq_change_text_domain('multilogin');
       logout_error(_("Invalid server selection"));
       exit;
 
@@ -112,8 +158,7 @@ function multilogin_insertIMAPSelection_do()
    load_config('multilogin', 'config.php');
 
 
-   bindtextdomain ('multilogin', SM_PATH . 'locale');
-   textdomain ('multilogin');
+   sq_change_text_domain('multilogin');
 
 
    // from SM 1.5.2 an up, just use our template, only need to 
@@ -124,11 +169,11 @@ function multilogin_insertIMAPSelection_do()
 
       global $oTemplate;
       $foundMatchingLoginServer = 0;
-      $remember = '';
+      $remember = NULL;
+      sqGetGlobalVar('rememberLoginServer', $remember, SQ_COOKIE); 
       foreach (array_keys($IMAPSelections) as $IMAPServer)
       {
-         if (sqGetGlobalVar('rememberLoginServer', $remember, SQ_COOKIE) 
-          && $remember == $IMAPServer)
+         if (!is_null($remember) && $remember == $IMAPServer)
             $foundMatchingLoginServer = 1;
 
       }
@@ -182,13 +227,14 @@ function multilogin_insertIMAPSelection_do()
          . "       <select name=\"loginServer\">\n";
 
       $foundMatchingLoginServer = 0;
+      $remember = NULL;
+      sqGetGlobalVar('rememberLoginServer', $remember, SQ_COOKIE); 
       foreach (array_keys($IMAPSelections) as $IMAPServer)
       {
 
          $output .= '          <option value="' . $IMAPServer . '"';
 
-         if (sqGetGlobalVar('rememberLoginServer', $remember, SQ_COOKIE) 
-          && $remember == $IMAPServer)
+         if (!is_null($remember) && $remember == $IMAPServer)
          {
             $output .= ' selected';
             $foundMatchingLoginServer = 1;
@@ -206,7 +252,7 @@ function multilogin_insertIMAPSelection_do()
       {
          $output .= "<tr><td><center><input type='checkbox'" .
             ($foundMatchingLoginServer ? ' checked' : '') . 
-            " name='rememberLoginServer' id='remember'><label for='remember'>" . 
+            " name='rememberLoginServer' id='remember' value='1'><label for='remember'>" . 
             _("Remember login server") . "</label>\n</center></td></tr>\n";
       }
       $output .= "</table>\n".
@@ -222,8 +268,7 @@ function multilogin_insertIMAPSelection_do()
 
    }
 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
+   sq_change_text_domain('squirrelmail');
 
 
    // depending on SM version, either return or display output
@@ -252,8 +297,9 @@ function multilogin_sqoverride_config_do($args='')
    if (sqsession_is_registered('config_override'))
    {
 
-      global $config_override, $plugins, $squirrelmail_plugin_hooks;
-      sqgetGlobalVar('config_override', $config_override, SQ_SESSION);
+      global $plugins, $squirrelmail_plugin_hooks;
+      $config_override = array();
+      sqGetGlobalVar('config_override', $config_override, SQ_SESSION);
       $already_enabled = array();
 
 
